@@ -1,28 +1,34 @@
 # 3p
-from ddtrace.vendor import wrapt
 import pymysql
 
 # project
-from ddtrace import config, Pin
+from ddtrace import Pin
+from ddtrace import config
 from ddtrace.contrib.dbapi import TracedConnection
-from ...ext import net, db
+from ddtrace.vendor import wrapt
+
+from ...ext import db
+from ...ext import net
 
 
-config._add("pymysql", dict(
-    # TODO[v1.0] this should be "mysql"
-    _default_service="pymysql",
-))
+config._add(
+    "pymysql",
+    dict(
+        # TODO[v1.0] this should be "mysql"
+        _default_service="pymysql",
+    ),
+)
 
 CONN_ATTR_BY_TAG = {
-    net.TARGET_HOST: 'host',
-    net.TARGET_PORT: 'port',
-    db.USER: 'user',
-    db.NAME: 'db',
+    net.TARGET_HOST: "host",
+    net.TARGET_PORT: "port",
+    db.USER: "user",
+    db.NAME: "db",
 }
 
 
 def patch():
-    wrapt.wrap_function_wrapper('pymysql', 'connect', _connect)
+    wrapt.wrap_function_wrapper("pymysql", "connect", _connect)
 
 
 def unpatch():
@@ -36,8 +42,8 @@ def _connect(func, instance, args, kwargs):
 
 
 def patch_conn(conn):
-    tags = {t: getattr(conn, a, '') for t, a in CONN_ATTR_BY_TAG.items()}
-    pin = Pin(app='pymysql', tags=tags)
+    tags = {t: getattr(conn, a, "") for t, a in CONN_ATTR_BY_TAG.items()}
+    pin = Pin(app="pymysql", tags=tags)
 
     # grab the metadata from the conn
     wrapped = TracedConnection(conn, pin=pin, cfg=config.pymysql)
