@@ -4,23 +4,36 @@ import sys
 import threading
 
 import ddtrace
-from ..api import Response
-from .. import compat
+
 from .. import _worker
+from .. import compat
+from ..api import Response
 from ..compat import httplib
+from ..constants import KEEP_SPANS_RATE_KEY
+from ..encoding import Encoder
+from ..encoding import JSONEncoderV2
 from ..sampler import BasePrioritySampler
-from ..encoding import Encoder, JSONEncoderV2
 from ..utils.time import StopWatch
+from .buffer import BufferFull
+from .buffer import BufferItemTooLarge
+from .buffer import TraceBuffer
 from .logger import get_logger
 from .runtime import container
-from .buffer import BufferFull, BufferItemTooLarge, TraceBuffer
+from .sma import SimpleMovingAverage
 from .uds import UDSHTTPConnection
 
+
 log = get_logger(__name__)
 
 DEFAULT_TIMEOUT = 5
 LOG_ERR_INTERVAL = 60
 
+# The window size should be chosen so that the look-back period is
+# greater-equal to the agent API's timeout. Although most tracers have a
+# 2s timeout, the java tracer has a 10s timeout, so we set the window size
+# to 10 buckets of 1s duration.
+DEFAULT_SMA_WINDOW = 10
+
 
 def _human_size(nbytes):
     """Return a human-readable size."""
@@ -121,21 +134,38 @@ class AgentWriter(_worker.PeriodicWorkerThread):
         self._encoder = Encoder()
         self._headers.update({"Content-Type": self._encoder.content_type})
 
-        self._started = False
         self._started_lock = threading.Lock()
         self.dogstatsd = dogstatsd
         self._report_metrics = report_metrics
         self._metrics_reset()
+        self._drop_sma = SimpleMovingAverage(DEFAULT_SMA_WINDOW)
 
     def _metrics_dist(self, name, count=1, tags=None):
-        if self._report_metrics:
-            self._metrics[name]["count"] += count
-            if tags:
-                self._metrics[name]["tags"].extend(tags)
+        self._metrics[name]["count"] += count
+        if tags:
+            self._metrics[name]["tags"].extend(tags)
 
     def _metrics_reset(self):
-        if self._report_metrics:
-            self._metrics = defaultdict(lambda: {"count": 0, "tags": []})
+        self._metrics = defaultdict(lambda: {"count": 0, "tags": []})
+
+    def _set_drop_rate(self):
+        dropped = sum(
+            self._metrics[metric]["count"]
+            for metric in ("encoder.dropped.traces", "buffer.dropped.traces", "http.dropped.traces")
+        )
+        accepted = self._metrics["writer.accepted.traces"]["count"]
+
+        if dropped > accepted:
+            # Sanity check, we cannot drop more traces than we accepted.
+            log.error("dropped more traces than accepted (dropped: %d, accepted: %d)", dropped, accepted)
+
+            accepted = dropped
+
+        self._drop_sma.set(dropped, accepted)
+
+    def _set_keep_rate(self, trace):
+        if trace:
+            trace[0].set_metric(KEEP_SPANS_RATE_KEY, 1.0 - self._drop_sma.get())
 
     def recreate(self):
         writer = self.__class__(
@@ -164,15 +194,15 @@ class AgentWriter(_worker.PeriodicWorkerThread):
             try:
                 conn.request("PUT", self._endpoint, data, headers)
                 resp = compat.get_connection_response(conn)
-                return Response.from_http_response(resp)
-            finally:
-                conn.close()
                 t = sw.elapsed()
                 if t >= self.interval:
                     log_level = logging.WARNING
                 else:
                     log_level = logging.DEBUG
                 log.log(log_level, "sent %s in %.5fs", _human_size(len(data)), t)
+                return Response.from_http_response(resp)
+            finally:
+                conn.close()
 
     @property
     def agent_url(self):
@@ -196,42 +226,38 @@ class AgentWriter(_worker.PeriodicWorkerThread):
 
         self._metrics_dist("http.requests")
 
-        try:
-            response = self._put(payload, headers)
-        except (httplib.HTTPException, OSError, IOError):
-            log.error("failed to send traces to Datadog Agent at %s", self.agent_url, exc_info=True)
-            if self._report_metrics:
-                self._metrics_dist("http.errors", tags=["type:err"])
-                self._metrics_dist("http.dropped.bytes", len(payload))
-        else:
-            if response.status >= 400:
-                self._metrics_dist("http.errors", tags=["type:%s" % response.status])
-            else:
-                self._metrics_dist("http.sent.bytes", len(payload))
+        response = self._put(payload, headers)
 
-            if response.status in [404, 415]:
-                log.debug("calling endpoint '%s' but received %s; downgrading API", self._endpoint, response.status)
-                try:
-                    payload = self._downgrade(payload, response)
-                except ValueError:
-                    log.error(
-                        "unsupported endpoint '%s': received response %s from Datadog Agent",
-                        self._endpoint,
-                        response.status,
-                    )
-                else:
-                    return self._send_payload(payload, count)
-            elif response.status >= 400:
+        if response.status >= 400:
+            self._metrics_dist("http.errors", tags=["type:%s" % response.status])
+        else:
+            self._metrics_dist("http.sent.bytes", len(payload))
+
+        if response.status in [404, 415]:
+            log.debug("calling endpoint '%s' but received %s; downgrading API", self._endpoint, response.status)
+            try:
+                payload = self._downgrade(payload, response)
+            except ValueError:
                 log.error(
-                    "failed to send traces to Datadog Agent at %s: HTTP error status %s, reason %s",
-                    self.agent_url,
+                    "unsupported endpoint '%s': received response %s from Datadog Agent",
+                    self._endpoint,
                     response.status,
-                    response.reason,
                 )
-                self._metrics_dist("http.dropped.bytes", len(payload))
-            elif self._priority_sampler or isinstance(self._sampler, BasePrioritySampler):
-                result_traces_json = response.get_json()
-                if result_traces_json and "rate_by_service" in result_traces_json:
+            else:
+                return self._send_payload(payload, count)
+        elif response.status >= 400:
+            log.error(
+                "failed to send traces to Datadog Agent at %s: HTTP error status %s, reason %s",
+                self.agent_url,
+                response.status,
+                response.reason,
+            )
+            self._metrics_dist("http.dropped.bytes", len(payload))
+            self._metrics_dist("http.dropped.traces", count)
+        elif self._priority_sampler or isinstance(self._sampler, BasePrioritySampler):
+            result_traces_json = response.get_json()
+            if result_traces_json and "rate_by_service" in result_traces_json:
+                try:
                     if self._priority_sampler:
                         self._priority_sampler.update_rate_by_service_sample_rates(
                             result_traces_json["rate_by_service"],
@@ -240,23 +266,29 @@ class AgentWriter(_worker.PeriodicWorkerThread):
                         self._sampler.update_rate_by_service_sample_rates(
                             result_traces_json["rate_by_service"],
                         )
+                except ValueError:
+                    log.error("sample_rate is negative, cannot update the rate samplers")
 
     def write(self, spans):
         # Start the AgentWriter on first write.
         # Starting it earlier might be an issue with gevent, see:
         # https://github.com/DataDog/dd-trace-py/issues/1192
-        if self._started is False:
+        if self.started is False:
             with self._started_lock:
-                if self._started is False:
+                if self.started is False:
                     self.start()
-                    self._started = True
         if not spans:
             return
 
+        self._metrics_dist("writer.accepted.traces")
+
+        self._set_keep_rate(spans)
+
         try:
             encoded = self._encoder.encode_trace(spans)
         except Exception:
             log.error("failed to encode trace with encoder %r", self._encoder, exc_info=True)
+            self._metrics_dist("encoder.dropped.traces", 1)
         else:
             try:
                 self._buffer.put(encoded)
@@ -284,25 +316,30 @@ class AgentWriter(_worker.PeriodicWorkerThread):
 
     def flush_queue(self):
         enc_traces = self._buffer.get()
-        if not enc_traces:
-            return
-
-        encoded = self._encoder.join_encoded(enc_traces)
-        self._send_payload(encoded, len(enc_traces))
-
-        if self._report_metrics:
-            # Note that we cannot use the batching functionality of dogstatsd because
-            # it's not thread-safe.
-            # https://github.com/DataDog/datadogpy/issues/439
-            # This really isn't ideal as now we're going to do a ton of socket calls.
+        if enc_traces:
+            encoded = self._encoder.join_encoded(enc_traces)
             try:
+                self._send_payload(encoded, len(enc_traces))
+            except (httplib.HTTPException, OSError, IOError):
+                log.error("failed to send traces to Datadog Agent at %s", self.agent_url, exc_info=True)
+                self._metrics_dist("http.errors", tags=["type:err"])
+                self._metrics_dist("http.dropped.bytes", len(encoded))
+                self._metrics_dist("http.dropped.traces", len(enc_traces))
+
+            if self._report_metrics:
+                # Note that we cannot use the batching functionality of dogstatsd because
+                # it's not thread-safe.
+                # https://github.com/DataDog/datadogpy/issues/439
+                # This really isn't ideal as now we're going to do a ton of socket calls.
                 self.dogstatsd.increment("datadog.tracer.http.requests")
                 self.dogstatsd.distribution("datadog.tracer.http.sent.bytes", len(encoded))
                 self.dogstatsd.distribution("datadog.tracer.http.sent.traces", len(enc_traces))
                 for name, metric in self._metrics.items():
                     self.dogstatsd.distribution("datadog.tracer.%s" % name, metric["count"], tags=metric["tags"])
-            finally:
-                self._metrics_reset()
+
+        self._set_drop_rate()
+
+        self._metrics_reset()
 
     def run_periodic(self):
         self.flush_queue()
